<?php
/**
 * Special Menu Section options
 *
 * @package Theme Palace
 * @subpackage Mezze
 * @since Mezze 1.0.0
 */

// Add Special Menu section
$wp_customize->add_section( 'mezze_special_menu_section', array(
	'title'             => esc_html__( 'Special Menu','mezze' ),
	'description'       => esc_html__( 'Special Menu Section options.', 'mezze' ),
	'panel'             => 'mezze_front_page_panel',
) );

// Special Menu content enable control and setting
$wp_customize->add_setting( 'mezze_theme_options[special_menu_section_enable]', array(
	'default'			=> 	$options['special_menu_section_enable'],
	'sanitize_callback' => 'mezze_sanitize_switch_control',
) );

$wp_customize->add_control( new Mezze_Switch_Control( $wp_customize, 'mezze_theme_options[special_menu_section_enable]', array(
	'label'             => esc_html__( 'Special Menu Section Enable', 'mezze' ),
	'section'           => 'mezze_special_menu_section',
	'on_off_label' 		=> mezze_switch_options(),
) ) );

// special_menu title setting and control
$wp_customize->add_setting( 'mezze_theme_options[special_menu_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['special_menu_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'mezze_theme_options[special_menu_title]', array(
	'label'           	=> esc_html__( 'Title', 'mezze' ),
	'section'        	=> 'mezze_special_menu_section',
	'active_callback' 	=> 'mezze_is_special_menu_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'mezze_theme_options[special_menu_title]', array(
		'selector'            => '#special-menu .section-header h2.section-title',
		'settings'            => 'mezze_theme_options[special_menu_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'mezze_special_menu_title_partial',
    ) );
}

// Special Menu image setting and control.
$wp_customize->add_setting( 'mezze_theme_options[special_menu_image]', array(
	'sanitize_callback' => 'mezze_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'mezze_theme_options[special_menu_image]',
		array(
		'label'       		=> esc_html__( 'Background Image', 'mezze' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'mezze' ), 1920, 1080 ),
		'section'     		=> 'mezze_special_menu_section',
		'active_callback'	=> 'mezze_is_special_menu_section_enable',
) ) );

// Special Menu content type control and setting
$wp_customize->add_setting( 'mezze_theme_options[special_menu_content_type]', array(
	'default'          	=> $options['special_menu_content_type'],
	'sanitize_callback' => 'mezze_sanitize_select',
) );

$wp_customize->add_control( 'mezze_theme_options[special_menu_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'mezze' ),
	'section'           => 'mezze_special_menu_section',
	'type'				=> 'select',
	'active_callback' 	=> 'mezze_is_special_menu_section_enable',
	'choices'			=> mezze_special_menu_content_type(),
) );

for ( $i = 1; $i <= 4; $i++ ) :

	// special_menu posts drop down chooser control and setting
	$wp_customize->add_setting( 'mezze_theme_options[special_menu_content_page_' . $i . ']', array(
		'sanitize_callback' => 'mezze_sanitize_page',
	) );

	$wp_customize->add_control( new Mezze_Dropdown_Chooser( $wp_customize, 'mezze_theme_options[special_menu_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'mezze' ), $i ),
		'section'           => 'mezze_special_menu_section',
		'choices'			=> mezze_page_choices(),
		'active_callback'	=> 'mezze_is_special_menu_section_content_page_enable',
	) ) );

	// special_menu posts drop down chooser control and setting
	$wp_customize->add_setting( 'mezze_theme_options[special_menu_content_product_' . $i . ']', array(
		'sanitize_callback' => 'mezze_sanitize_page',
	) );

	$wp_customize->add_control( new Mezze_Dropdown_Chooser( $wp_customize, 'mezze_theme_options[special_menu_content_product_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Product %d', 'mezze' ), $i ),
		'section'           => 'mezze_special_menu_section',
		'choices'			=> mezze_product_choices(),
		'active_callback'	=> 'mezze_is_special_menu_section_content_product_enable',
	) ) );

endfor;
